@@ -41,7 +41,7 @@ class OracledbPooledPersistenceEngine(PersistenceEngine):
         return ":" + name
 
     def _get_connection(self):
-        return self.__pool.acquire(user=self.__user, password=self.__password)
+        return self.__pool.acquire()
 
     def _set_clob(self, value):
         if type(value) == oracledb.LOB:
