@@ -61,7 +61,7 @@ class CruiseProcessor(object):
         self.file_parameters = []
         self.file_access_path_mappings = []
         self.access_path_cache = Cache()
-        self.migrating_surveys: [MigratingSurvey] = set()
+        self.migrating_surveys: set[MigratingSurvey] = set()
 
     def ship(self, cruise_cargo: [CruiseCargo]):
         try:
